==> haskell-zlib-0.7.0.0-63-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   zlib
version:                0.7.0.0
visibility:             public
id:                     zlib-0.7.0.0-8ZqFqGsvFQB8ur6Sh8fLj0
key:                    zlib-0.7.0.0-8ZqFqGsvFQB8ur6Sh8fLj0
license:                BSD-3-Clause
copyright:              (c) 2006-2016 Duncan Coutts
maintainer:
    Duncan Coutts <duncan@community.haskell.org>, Andrew Lelechenko <andrew.lelechenko@gmail.com>, Emily Pillmore <emilypi@cohomolo.gy>, Herbert Valerio Riedel <hvr@gnu.org>

author:                 Duncan Coutts <duncan@community.haskell.org>
synopsis:               Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.

category:               Codec
abi:                    6f3ed4a9240eb1221c3696f9cd6d1c23
exposed:                True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw

hidden-modules:
    Codec.Compression.Zlib.Stream
    Codec.Compression.Zlib.ByteStringCompat

import-dirs:            /usr/lib/ghc-9.4.8/site-local/zlib-0.7.0.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/zlib-0.7.0.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/zlib-0.7.0.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-zlib
hs-libraries:           HSzlib-0.7.0.0-8ZqFqGsvFQB8ur6Sh8fLj0
extra-libraries:        z
extra-libraries-static: z
includes:               zlib.h hs-zlib.h
depends:                base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:     /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html:           /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-0.7.0.0-68-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   zlib
version:                0.7.0.0
visibility:             public
id:                     zlib-0.7.0.0-DS6Da0uFkVx9bSXatFvIRX
key:                    zlib-0.7.0.0-DS6Da0uFkVx9bSXatFvIRX
license:                BSD-3-Clause
copyright:              (c) 2006-2016 Duncan Coutts
maintainer:
    Duncan Coutts <duncan@community.haskell.org>, Andrew Lelechenko <andrew.lelechenko@gmail.com>, Emily Pillmore <emilypi@cohomolo.gy>, Herbert Valerio Riedel <hvr@gnu.org>

author:                 Duncan Coutts <duncan@community.haskell.org>
synopsis:               Compression and decompression in the gzip and zlib formats
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the
    <https://en.wikipedia.org/wiki/Zlib zlib C library>
    so it has high performance. It supports the \"zlib\",
    \"gzip\" and \"raw\" compression formats.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full zlib feature set.

category:               Codec
abi:                    0b524036d6f1f90ecbe1a5d21735c166
exposed:                True
exposed-modules:
    Codec.Compression.GZip Codec.Compression.Zlib
    Codec.Compression.Zlib.Internal Codec.Compression.Zlib.Raw

hidden-modules:
    Codec.Compression.Zlib.Stream
    Codec.Compression.Zlib.ByteStringCompat

import-dirs:            /usr/lib/ghc-9.6.7.20250817/site-local/zlib-0.7.0.0
library-dirs:
    /usr/lib/ghc-9.6.7.20250817/site-local/zlib-0.7.0.0 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.7.20250817/site-local/zlib-0.7.0.0 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-zlib
hs-libraries:           HSzlib-0.7.0.0-DS6Da0uFkVx9bSXatFvIRX
extra-libraries:        z
extra-libraries-static: z
include-dirs:           /usr/include
includes:               zlib.h hs-zlib.h
depends:                base-4.18.3.0 bytestring-0.11.5.4
haddock-interfaces:     /usr/share/doc/haskell-zlib/html/zlib.haddock
haddock-html:           /usr/share/doc/haskell-zlib/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
